from distutils.core import setup
setup(
    name='firstpypiFab',
    packages=['firstpypiFab'],
    version='0.1.1',
    description='First pypi Fab',
    author='Fabian Flores',
    author_email='favian.flone92@gmail.com',
    url='https://github.com/Fabfm4/firstpypi',
    download_url='https://github.com/Fabfm4/firstpypi/tarball/0.1.1',
    keywords=['HelloWorld', 'firstpypiFab'],
    classifiers=[],
)
